package wspay

type CreateTransaction struct {
	ShopID         string `json:"ShopID"`
	ShoppingCardID string `json:"ShoppingCartID"`
	Version        string `json:"Version"`
	TotalAmount    string `json:"TotalAmount"`
	ReturnUrl      string `json:"ReturnURL"`
	ReturnErrorUrl string `json:"ReturnErrorURL"`
	CancelUrl      string `json:"CancelURL"`
	Signature      string `json:"Signature"`
}

type TransactionResponse struct {
	TransactionId  *string `json:"TransactionId"`
	PaymentFormUrl *string `json:"PaymentFormUrl"`
}

type FormReturn struct {
	CustomerFirstName        string `form:"CustomerFirstname"`
	CustomerSurname          string `form:"CustomerSurname"`
	CustomerAddress          string `form:"CustomerAddress"`
	CustomerCity             string `form:"CustomerCity"`
	CustomerZIP              string `form:"CustomerZIP"`
	CustomerCountry          string `form:"CustomerCountry"`
	CustomerPhone            string `form:"CustomerPhone"`
	CustomerEmail            string `form:"CustomerEmail"`
	ShoppingCartID           string `form:"ShoppingCartID"`
	Lang                     string `form:"Lang"`
	DateTime                 string `form:"DateTime"` //yyyymmddHHMMss
	Amount                   string `form:"Amount"`   // eg. 123,43
	ECI                      string `form:"ECI"`
	STAN                     string `form:"STAN"`
	Partner                  string `form:"Partner"`
	WsPayOrderId             string `form:"WsPayOrderId"`
	PaymentType              string `form:"PaymentType"`
	CreditCardNumber         string `form:"CreditCardNumber"` // masked number
	PaymentPlan              string `form:"PaymentPlan"`
	ShopPostedPaymentPlan    string `form:"ShopPostedPaymentPlan"`
	ShopPostedLang           string `form:"ShopPostedLang"`
	ShopPostedCreditCardName string `form:"ShopPostedCreditCardName"`
	Success                  int    `form:"Success"`
	ApprovalCode             string `form:"ApprovalCode"`
	ErrorMessage             string `form:"ErrorMessage"`
	ShopPostedPaymentMethod  string `form:"ShopPostedPaymentMethod"`
	Signature                string `form:"Signature"`
}

type FormError struct {
	CustomerFirstName        string
	CustomerSurname          string
	CustomerAddress          string
	CustomerCity             string
	CustomerZIP              string
	CustomerCountry          string
	CustomerPhone            string
	CustomerEmail            string
	ShoppingCartID           string
	Lang                     string
	DateTime                 string //yyyymmddHHMMss
	Amount                   string // eg. 123,43
	ECI                      string
	PaymentType              string
	PaymentPlan              string
	ShopPostedPaymentPlan    string
	ShopPostedLang           string
	ShopPostedCreditCardName string
	Success                  int
	ApprovalCode             string
	ErrorMessage             string
	ShopPostedPaymentMethod  string
	ErrorCodes               string
	Signature                string
}

type FormCancel struct {
	ResponseCode   int
	ShoppingCartID string
	ApprovalCode   string
	Success        int
	Signature      string
}

type CompletionRequest struct {
	Version      string
	WsPayOrderId string
	ShopId       string
	ApprovalCode string
	STAN         string
	Amount       int64
	Signature    string
}

type CompletionResponse struct {
	WsPayOrderId  string
	ShopId        string
	ApprovalCode  string
	STAN          string
	ErrorMessage  string
	ActionSuccess string
	Signature     string
}

type StatusCheckRequest struct {
	Version        string
	ShopId         string
	ShoppingCartId string
	Signature      string
}

type StatusCheckResponse struct {
	WsPayOrderId                    string
	Signature                       string
	STAN                            string
	ApprovalCode                    string
	ShopID                          string
	ShoppingCartID                  string
	Amount                          int64
	CurrencyCode                    string
	ActionSuccess                   string
	Success                         string // deprecated
	Authorized                      string
	Completed                       string
	Voided                          string
	Refunded                        string
	PaymentPlan                     string
	Partner                         string
	OnSite                          int
	CreditCardName                  string
	CreditCardNumber                string
	ECI                             string
	CustomerFirstName               string
	CustomerLastName                string
	CustomerCity                    string
	CustomerZIP                     string
	CustomerCountry                 string
	CustomerPhone                   string
	CustomerEmail                   string
	TransactionDateTime             string // yyyymmddHHMMss
	IsLessThan30DaysFromTransaction bool
	CanBeCompleted                  bool
	CanBeVoided                     bool
	CanBeRefunded                   bool
	ExpirationDate                  string
}
